#include "common.h"
#include "CommPort.h"
#include "../util.h"
#include "../resource.h"

CCommPort::CCommPort():
	m_hCommHandle(INVALID_HANDLE_VALUE),
	m_strPortName(_T("NUL")),
	m_iBaudRate(9600),
	m_cParity(NOPARITY),
	m_cStopBits(ONESTOPBIT)
{
}

CCommPort::~CCommPort()
{
	Finish();
}

//
bool CCommPort::Init(LPCTSTR lpszPortName,int iBaudRate,BYTE cParity,BYTE cStopBits)
{
	Finish();
	m_strPortName=lpszPortName;
	m_iBaudRate=iBaudRate;

	//|[gI[v
	m_hCommHandle=CreateFile(m_strPortName,GENERIC_WRITE,0,NULL,OPEN_EXISTING,FILE_ATTRIBUTE_NORMAL,NULL);

	if(INVALID_HANDLE_VALUE==m_hCommHandle){
		TRACE("Failed to CreateFile(COM port)\n");
		UtilErrorMessage(NULL,CString(MAKEINTRESOURCE(IDS_ERROR_OPENPORT)));
		Finish();
		return false;
	}

	//|[gݒ
	DCB Conf={0};
	Conf.DCBlength=sizeof(Conf);
	GetCommState(m_hCommHandle,&Conf);

	Conf.BaudRate=m_iBaudRate;		//{[[g
	Conf.ByteSize=8;			//oCgTCY
	Conf.fParity=(cParity==NOPARITY ? 0:1);			//peB
	Conf.Parity=cParity;
	Conf.StopBits=cStopBits;	//Xgbvrbg

	m_cParity=cParity;
	m_cStopBits=cStopBits;

	if(SetCommState(m_hCommHandle,&Conf))return true;

	TRACE("Failed to SetCommState()\n");
	UtilErrorMessage(NULL,CString(MAKEINTRESOURCE(IDS_ERROR_SETCOMMSTATE)));
	Finish();
	return false;
}

//I
bool CCommPort::Finish()
{
	if(INVALID_HANDLE_VALUE!=m_hCommHandle){
		CloseHandle(m_hCommHandle);
		m_hCommHandle=INVALID_HANDLE_VALUE;
	}
	m_strPortName=_T("NUL");
	m_iBaudRate=9600;
	m_cParity=NOPARITY;
	m_cStopBits=ONESTOPBIT;
	return true;
}

//oCg񑗐M
bool CCommPort::SendData(LPCBYTE lpByte,DWORD dwSize)
{
//	ASSERT(INVALID_HANDLE_VALUE!=hCommHandle);
	if(INVALID_HANDLE_VALUE==m_hCommHandle){
		TRACE("COM Port is *NOT* ready.\n");
		return false;
	}

	DWORD dwWritten;

	//M
	if(WriteFile(m_hCommHandle,lpByte,dwSize,&dwWritten,NULL)&&dwWritten==dwSize){
		return true;
	}

	TRACE("Failed to WriteFile(COM)\n");
	UtilErrorMessage(NULL,CString(MAKEINTRESOURCE(IDS_ERROR_SENDDATA)));
	return false;
}
